pub enum SimpleQueryStringQueryFlags {
Show 13 variants
All,
And,
Escape,
Fuzzy,
Near,
None,
Not,
Or,
Phrase,
Precedence,
Prefix,
Slop,
Whitespace,
}Expand description
You can use the flags parameter to enable more optional operators for Lucene’s regular expression engine.
Variants
All
Enables all optional operators.
And
Enables the + AND operator.
Escape
Enables \ as an escape character.
Fuzzy
Enables the ~N operator after a word, where N is an integer
denoting the allowed edit distance for matching. See
Fuzziness.
Near
Enables the ~N operator, after a phrase where N is the maximum
number of positions allowed between matching tokens. Synonymous to
SLOP.
None
Disables all operators.
Not
Enables the - NOT operator.
Or
Enables the \| OR operator.
Phrase
Enables the " quotes operator used to search for phrases.
Precedence
Enables the ( and ) operators to control operator precedence.
Prefix
Enables the * prefix operator.
Slop
Enables the ~N operator, after a phrase where N is maximum
number of positions allowed between matching tokens. Synonymous to
NEAR.
Whitespace
Enables whitespace as split characters.