pub enum TextQueryType {
BestFields,
MostFields,
CrossFields,
Phrase,
PhrasePrefix,
BoolPrefix,
}Expand description
The way the multi_match query is executed internally.
Variants
BestFields
Finds documents which match any field, but uses the _score from the
best field. See
best_fields.
MostFields
Finds documents which match any field and combines the _score from
each field. See
most_fields.
CrossFields
Treats fields with the same analyzer as though they were one big
field. Looks for each word in any field. See
cross_fields.
Phrase
Runs a match_phrase query on each field and uses the _score from
the best field. See
phrase and phrase_prefix.
PhrasePrefix
Runs a match_phrase_prefix query on each field and uses the _score
from the best field. See
phrase and phrase_prefix.
BoolPrefix
Creates a match_bool_prefix query on each field and combines the
_score from each field. See
bool_prefix.