pub struct ShapeQuery { /* private fields */ }Expand description
Queries documents that contain fields indexed using the shape type.
Requires the shape Mapping.
https://www.elastic.co/guide/en/opensearch/reference/current/query-dsl-shape-query.html
Implementations
Sourceimpl<'de> ShapeQuery
impl<'de> ShapeQuery
pub fn deserialize<__D>(__deserializer: __D) -> Result<ShapeQuery, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl ShapeQuery
impl ShapeQuery
pub fn serialize<__S>(
__self: &ShapeQuery,
__serializer: __S,
) -> Result<__S::Ok, __S::Error>where
__S: Serializer,
Sourceimpl ShapeQuery
impl ShapeQuery
Sourcepub fn boost<T>(self, boost: T) -> Selfwhere
T: AsPrimitive<f32>,
pub fn boost<T>(self, boost: T) -> Selfwhere
T: AsPrimitive<f32>,
Floating point number used to decrease or increase the
relevance scores
of a query. Defaults to 1.0.
You can use the boost parameter to adjust relevance scores for searches containing two or more queries.
Boost values are relative to the default value of 1.0.
A boost value between 0 and 1.0 decreases the relevance score.
A value greater than 1.0 increases the relevance score.
Sourcepub fn name<S>(self, name: S) -> Selfwhere
S: ToString,
pub fn name<S>(self, name: S) -> Selfwhere
S: ToString,
You can use named queries to track which queries matched
returned documents. If named queries are used, the response
includes a matched_queries property for each hit.
https://www.elastic.co/guide/en/opensearch/reference/current/query-dsl-bool-query.html#named-queries
Sourcepub fn relation(self, relation: SpatialRelation) -> Self
pub fn relation(self, relation: SpatialRelation) -> Self
The shape strategy mapping parameter determines which spatial relation operators may be used at search time.
Sourcepub fn ignore_unmapped(self, ignore_unmapped: bool) -> Self
pub fn ignore_unmapped(self, ignore_unmapped: bool) -> Self
When set to true the ignore_unmapped option will ignore an unmapped
field and will not match any documents for this query. This can be
useful when querying multiple indexes which might have different
mappings. When set to false (the default value) the query will throw
an exception if the field is not mapped.