pub struct SpanFieldMaskingQuery { /* private fields */ }Expand description
Wrapper to allow span queries to participate in composite single-field span
queries by lying about their search field. The span field masking query
maps to Lucene’s SpanFieldMaskingQuery
This can be used to support queries like span-near or span-or across
different fields, which is not ordinarily permitted.
Span field masking query is invaluable in conjunction with multi-fields when same content is indexed with multiple analyzers. For instance we could index a field with the standard analyzer which breaks text up into words, and again with the english analyzer which stems words into their root form.
Note: as span field masking query returns the masked field, scoring will be done using the norms of the field name supplied. This may lead to unexpected scoring behavior.
https://www.elastic.co/guide/en/opensearch/reference/current/query-dsl-span-field-masking-query.html
Implementations
Sourceimpl<'de> SpanFieldMaskingQuery
impl<'de> SpanFieldMaskingQuery
pub fn deserialize<__D>(
__deserializer: __D,
) -> Result<SpanFieldMaskingQuery, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl SpanFieldMaskingQuery
impl SpanFieldMaskingQuery
pub fn serialize<__S>(
__self: &SpanFieldMaskingQuery,
__serializer: __S,
) -> Result<__S::Ok, __S::Error>where
__S: Serializer,